<?php

namespace Drupal\eat\Form;

use Drupal\Core\Entity\EntityTypeBundleInfo;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\ContentEntityType;
use Drupal\taxonomy\Entity\Vocabulary;

class EatAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'eat_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['eat.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    drupal_set_message(t('Only node is currently available'), 'warning');
    // Get all configuration required for this form.
    $config = $this->config('eat.settings');

    // Show all available entity types.
    $content_entity_types = [];
    $entity_type_definitions = \Drupal::entityTypeManager()->getDefinitions();
    foreach ($entity_type_definitions as $definition) {
      if ($definition instanceof ContentEntityType) {
        $entity_type_id = $definition->getProvider();

        $form[$entity_type_id] = [
          '#type' => 'details',
          '#collapsed' => TRUE,
          '#collapsible' => TRUE,
          '#title' => $entity_type_id,
        ];

        // For node(s) only right now.
        if ($entity_type_id == 'node') {
          $types = \Drupal::entityTypeManager()
            ->getStorage('node_type')
            ->loadMultiple();
          $content_entity_types[$entity_type_id] = $definition->getLabel();

          $bundles = array();
          foreach ($types as $type) {
            $name = $type->get('name');
            $key = $type->get('type');
            $bundles[$entity_type_id.'-'.$key] = $name;
          }
          $b = $config->get('bundles');
          $form[$entity_type_id]['bundles'] = [
            '#type' => 'checkboxes',
            '#options' => $bundles,
            '#default_value' => $b
          ];
        }

      }
    }

    // Taxonomy Vocabulary.
    // @todo: move into individual items.
    $vocabularies = Vocabulary::loadMultiple();
    $vocabulary_items = array();
    foreach ($vocabularies as $vocabulary) {
      $vocabulary_items[$vocabulary->get('vid')] = $vocabulary->get('name');
    }
    $form['vocabularies'] = [
      '#type' => 'select',
      '#description' => $this->t('Set vocabularies to entity types and bundles.'),
      '#title' => $this->t('Vocabularies'),
      '#multiple' => TRUE,
      '#options' => $vocabulary_items,
      '#default_value' => $config->get('vocabularies'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    // Get config.
    \Drupal::configFactory()->getEditable('eat.settings')
      ->set('bundles', $form_state->getValue('bundles'))
      ->set('vocabularies', $form_state->getValue('vocabularies'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
